@@ -5,7 +5,7 @@
 package bifs
 
 import (
-	"github.com/johnkerl/miller/pkg/mlrval"
+	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
 func BIF_logical_NOT(input1 *mlrval.Mlrval) *mlrval.Mlrval {
