@@ -42,8 +42,8 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/johnkerl/miller/pkg/colorizer"
-	"github.com/johnkerl/miller/pkg/lib"
+	"github.com/johnkerl/miller/v6/pkg/colorizer"
+	"github.com/johnkerl/miller/v6/pkg/lib"
 )
 
 // ----------------------------------------------------------------
