@@ -94,11 +94,21 @@ func ParseCommandLine(
 ) {
 	// mlr -s scriptfile {data-file names ...} means take the contents of
 	// scriptfile as if it were command-line items.
+
 	args, err = maybeInterpolateDashS(args)
 	if err != nil {
 		return nil, nil, err
 	}
 
+	// Expand "-xyz" into "-x -y -z" while leaving "--xyz" intact. This is a
+	// keystroke-saver for the user.
+	//
+	// This is OK to do globally here since Miller is quite consistent (in
+	// main, verbs, and auxents) that multi-character options start with two
+	// dashes, e.g. "--csv". (The sole exception is the sort verb's -nf/-nr
+	// which are handled specially there.)
+	args = lib.Getoptify(args)
+
 	// Pass one as described at the top of this file.
 	flagSequences, terminalSequence, verbSequences, dataFileNames := parseCommandLinePassOne(args)
 
@@ -192,8 +202,8 @@ func parseCommandLinePassOne(
 			transformerSetup := transformers.LookUp(verb)
 			if transformerSetup == nil {
 				fmt.Fprintf(os.Stderr,
-					"%s: verb \"%s\" not found. Please use \"%s --help\" for a list.\n",
-					"mlr", verb, "mlr")
+					"mlr: verb \"%s\" not found. Please use \"mlr -l\" for a list.\n",
+					verb)
 				os.Exit(1)
 			}
 
@@ -295,7 +305,7 @@ func parseCommandLinePassTwo(
 		rc := cli.FLAG_TABLE.Parse(args, argc, &argi, options)
 
 		// Should have been parsed OK in pass one.
-		lib.InternalCodingErrorIf(rc != true)
+		lib.InternalCodingErrorIf(!rc)
 		// Make sure we consumed the entire flag sequence as parsed by pass one.
 		lib.InternalCodingErrorIf(argi != argc)
 	}
@@ -394,7 +404,7 @@ func parseCommandLinePassTwo(
 		options.FileNames = nil
 	}
 
-	if options.DoInPlace && (options.FileNames == nil || len(options.FileNames) == 0) {
+	if options.DoInPlace && len(options.FileNames) == 0 {
 		fmt.Fprintf(os.Stderr, "%s: -I option (in-place operation) requires input files.\n", "mlr")
 		os.Exit(1)
 	}
