@@ -61,12 +61,12 @@ func (node *CondBlockNode) Execute(
 		boolValue = false
 	} else if !isBool {
 		return nil, fmt.Errorf(
-			"mlr: conditional expression did not evaluate to boolean%s.",
+			"mlr: conditional expression did not evaluate to boolean%s",
 			dsl.TokenToLocationInfo(node.conditionToken),
 		)
 	}
 
-	if boolValue == true {
+	if boolValue {
 		blockExitPayload, err := node.statementBlockNode.Execute(state)
 		if err != nil {
 			return nil, err
