@@ -4,8 +4,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/johnkerl/miller/pkg/colorizer"
-	"github.com/johnkerl/miller/pkg/lib"
+	"github.com/johnkerl/miller/v6/pkg/colorizer"
+	"github.com/johnkerl/miller/v6/pkg/lib"
 )
 
 // ----------------------------------------------------------------
