@@ -29,9 +29,9 @@ func ValidateAST(
 
 	// They can do mlr put '': there are simply zero statements.
 	// But filter '' is an error.
-	if ast.RootNode.Children == nil || len(ast.RootNode.Children) == 0 {
+	if len(ast.RootNode.Children) == 0 {
 		if dslInstanceType == DSLInstanceTypeFilter {
-			return fmt.Errorf("mlr: filter statement must not be empty.")
+			return fmt.Errorf("mlr: filter statement must not be empty")
 		}
 	}
 
@@ -80,7 +80,7 @@ func validateASTAux(
 	if astNode.Type == dsl.NodeTypeFilterStatement {
 		if dslInstanceType == DSLInstanceTypeFilter {
 			return fmt.Errorf(
-				"mlr: filter expressions must not also contain the \"filter\" keyword.",
+				`mlr: filter expressions must not also contain the "filter" keyword`,
 			)
 		}
 	}
@@ -89,21 +89,21 @@ func validateASTAux(
 	if astNode.Type == dsl.NodeTypeBeginBlock {
 		if !atTopLevel {
 			return fmt.Errorf(
-				"mlr: begin blocks can only be at top level.",
+				"mlr: begin blocks can only be at top level",
 			)
 		}
 		nextLevelInBeginOrEnd = true
 	} else if astNode.Type == dsl.NodeTypeEndBlock {
 		if !atTopLevel {
 			return fmt.Errorf(
-				"mlr: end blocks can only be at top level.",
+				"mlr: end blocks can only be at top level",
 			)
 		}
 		nextLevelInBeginOrEnd = true
 	} else if astNode.Type == dsl.NodeTypeNamedFunctionDefinition {
 		if !atTopLevel {
 			return fmt.Errorf(
-				"mlr: func blocks can only be at top level.",
+				"mlr: func blocks can only be at top level",
 			)
 		}
 		nextLevelInUDF = true
@@ -112,7 +112,7 @@ func validateASTAux(
 	} else if astNode.Type == dsl.NodeTypeSubroutineDefinition {
 		if !atTopLevel {
 			return fmt.Errorf(
-				"mlr: subr blocks can only be at top level.",
+				"mlr: subr blocks can only be at top level",
 			)
 		}
 		nextLevelInUDS = true
@@ -134,7 +134,7 @@ func validateASTAux(
 			astNode.Type == dsl.NodeTypeIndirectFieldValue ||
 			astNode.Type == dsl.NodeTypeFullSrec {
 			return fmt.Errorf(
-				"mlr: begin/end blocks cannot refer to records via $x, $*, etc.",
+				"mlr: begin/end blocks cannot refer to records via $x, $*, etc",
 			)
 		}
 	}
@@ -143,7 +143,7 @@ func validateASTAux(
 	if !inLoop {
 		if astNode.Type == dsl.NodeTypeBreak {
 			return fmt.Errorf(
-				"mlr: break statements are only valid within for/do/while loops.",
+				"mlr: break statements are only valid within for/do/while loops",
 			)
 		}
 	}
@@ -151,7 +151,7 @@ func validateASTAux(
 	if !inLoop {
 		if astNode.Type == dsl.NodeTypeContinue {
 			return fmt.Errorf(
-				"mlr: break statements are only valid within for/do/while loops.",
+				"mlr: break statements are only valid within for/do/while loops",
 			)
 		}
 	}
@@ -169,7 +169,7 @@ func validateASTAux(
 	if !inUDF && !inUDS {
 		if astNode.Type == dsl.NodeTypeReturn {
 			return fmt.Errorf(
-				"mlr: return statements are only valid within func/subr blocks.",
+				"mlr: return statements are only valid within func/subr blocks",
 			)
 		}
 	}
@@ -179,14 +179,14 @@ func validateASTAux(
 		if inUDF {
 			if len(astNode.Children) != 1 {
 				return fmt.Errorf(
-					"mlr: return statements in func blocks must return a value.",
+					"mlr: return statements in func blocks must return a value",
 				)
 			}
 		}
 		if inUDS {
 			if len(astNode.Children) != 0 {
 				return fmt.Errorf(
-					"mlr: return statements in subr blocks must not return a value.",
+					"mlr: return statements in subr blocks must not return a value",
 				)
 			}
 		}
@@ -197,7 +197,7 @@ func validateASTAux(
 		ok := VALID_LHS_NODE_TYPES[astNode.Type]
 		if !ok {
 			return fmt.Errorf(
-				"mlr: %s is not valid on the left-hand side of an assignment.",
+				"mlr: %s is not valid on the left-hand side of an assignment",
 				astNode.Type,
 			)
 		}
@@ -208,7 +208,7 @@ func validateASTAux(
 		ok := VALID_LHS_NODE_TYPES[astNode.Type]
 		if !ok {
 			return fmt.Errorf(
-				"mlr: %s is not valid for unset statement.",
+				"mlr: %s is not valid for unset statement",
 				astNode.Type,
 			)
 		}
@@ -259,7 +259,7 @@ func validateForLoopTwoVariableUniqueNames(astNode *dsl.ASTNode) error {
 	keyVarName := string(keyVarNode.Token.Lit)
 	valVarName := string(valVarNode.Token.Lit)
 	if keyVarName == valVarName {
-		return fmt.Errorf("mlr: redefinition of variable %s in the same scope.", keyVarName)
+		return fmt.Errorf("mlr: redefinition of variable %s in the same scope", keyVarName)
 	} else {
 		return nil
 	}
@@ -289,14 +289,14 @@ func validateForLoopMultivariableUniqueNames(astNode *dsl.ASTNode) error {
 		name := string(keyVarNode.Token.Lit)
 		_, present := seen[name]
 		if present {
-			return fmt.Errorf("mlr: redefinition of variable %s in the same scope.", name)
+			return fmt.Errorf("mlr: redefinition of variable %s in the same scope", name)
 		}
 		seen[name] = true
 	}
 
 	valVarName := string(valVarNode.Token.Lit)
 	if seen[valVarName] {
-		return fmt.Errorf("mlr: redefinition of variable %s in the same scope.", valVarName)
+		return fmt.Errorf("mlr: redefinition of variable %s in the same scope", valVarName)
 	}
 
 	return nil
