@@ -70,7 +70,7 @@ func channelWriterHandleBatch(
 
 			// XXX more
 			// XXX also make sure this results in exit 1 & goroutine cleanup
-			if writerOptions.FailOnDataError {
+			if writerOptions.FailOnDataError && record != nil {
 				ok := true
 				for pe := record.Head; pe != nil; pe = pe.Next {
 					if pe.Value.IsError() {
