@@ -7,7 +7,7 @@ package utils
 import (
 	"container/list"
 
-	"github.com/johnkerl/miller/pkg/mlrval"
+	"github.com/johnkerl/miller/v6/pkg/mlrval"
 )
 
 // ----------------------------------------------------------------
